# segy files
EW0210_SEGY = /net/server/ohad/dat/EW0210/

# This is the X,Y origins of the first file (ar54.6721.ew0210.09.none.segy). Since they rest of the files are along the same line, we get the source positions relative to the first source in this file.
X_ORIG = -23613786
Y_ORIG =   4939432
# scalco field in the SU file is 10, meaning decimeters.
SCALCO = 10

L = $(tlag)
ifndef L
    L = 12 
endif

VERB=1

EW0210 = dat/EW0210.H
ew0210pow = 1.


# eps is the symmetry regularization, eps1 is the late-lag regularization
eps = eps=1e+3 eps1=1e+5

# these values are good for the middle offset
#eps = eps=1e+6 eps1=1e+4 and lag of 7

greyew0210s = min1=3 max1=5.2
greyew0210m = min1=3.9 max1=5.4
greyew0210l = min1=5.2 max1=6.7

# I calculated these from the s_x,s_y fields
nshots = 900
oshots = 0.
dshots = 10.5
# According to chief scientist Daniel Lizarralde, this is the streamer configuration for each shot
nrecs = 480
orecs = -6168
drecs = 12.5


EW0210_SHOTLABEL = "labels=clipped shot waveform where data gained BEFORE decon lag=$L : clipped shot waveform where data gained AFTER decon lag=$L : shot waveform where data gained AFTER decon lag=$L"
#####################################################
######### Segy2sep #################################

${D}/EW0210_%_orig.H: ${EW0210_SEGY}/ar54.%.ew0210.09.none.segy
	segyread tape=$< ns=4096 | segyclean | sushw key=hour a=1 b=0 c=1 d=0 > ${EW0210_SEGY}/EW0210_$*.su
	Su2sep < ${EW0210_SEGY}/EW0210_$*.su hff=$@@@ > $@

${D}/EW0210_%.H: ${D}/EW0210_%_orig.H
	Headermath < $< \
	key1=s_x eqn1="(sx-${X_ORIG})/${SCALCO}" key2=s_y eqn2="(sy-${Y_ORIG})/${SCALCO}" \
	key3=g_x eqn3="(gx-${X_ORIG})/${SCALCO}" key4=g_y eqn4="(gy-${Y_ORIG})/${SCALCO}" \
	key4=h_x eqn4="offset" \
 	hff=$@@@ > $@

EW0210_SEGY2SEP:
	make dat/EW0210_6721_orig.H dat/EW0210_6722_orig.H dat/EW0210_6723_orig.H dat/EW0210_6724_orig.H dat/EW0210_6725_orig.H
	make dat/EW0210_6726_orig.H dat/EW0210_6727_orig.H dat/EW0210_6728_orig.H dat/EW0210_6729_orig.H dat/EW0210_6730_orig.H
	make dat/EW0210_6721.H dat/EW0210_6722.H dat/EW0210_6723.H dat/EW0210_6724.H dat/EW0210_6725.H
	make dat/EW0210_6726.H dat/EW0210_6727.H dat/EW0210_6728.H dat/EW0210_6729.H dat/EW0210_6730.H

# This concatenates the 10 files I got from the UTIG website. I use this as the data.
# Each file has 90 shots with 480 offsets ranging from -6168 to -180, for a total of 900 shots.
${D}/EW0210.H: ${D}/EW0210_6721.H ${D}/EW0210_6722.H ${D}/EW0210_6723.H ${D}/EW0210_6724.H ${D}/EW0210_6725.H ${D}/EW0210_6726.H ${D}/EW0210_6727.H ${D}/EW0210_6728.H ${D}/EW0210_6729.H ${D}/EW0210_6730.H
	Cat3d $^ axis=2 > ${D}/tmpEW.H hff=${D}/tmpEW.H@@
	Infill3d < ${D}/tmpEW.H maxsize=6912000 > $@
	echo "n2=${nrecs}" >> $@
	echo "d2=${drecs}" >> $@
	echo "o2=${orecs}" >> $@
	echo "label2=X (m)" >> $@
	echo "n3=${nshots}" >> $@
	echo "d3=${dshots}" >> $@
	echo "o3=${oshots}" >> $@
	echo "label3=Shot position (m)" >> $@
	
# This sorts by offset. Quite useless....
#${D}/EW0210_byoff.H: ${D}/EW0210.H
#	Sort3d < $< nkeys=1 key1=h_x ng1=480 dg1=12.5 og1=-6168 hff=$@@@ gff=$@@@@@ > $@

#${D}/EW0210_off_%.H: ${D}/EW0210.H
#	Sort3d < $< nkeys=1 key1=h_x ng1=1 dg1=12.0 og1=-$* hff=${D}/tmpoff.H@@ gff=${D}/tmpoff.H@@@@ > ${D}/tmpoff.H
#	Infill3d < ${D}/tmpoff.H > $@
#	echo "label2=X (m)" >> $@
#	echo "o2=0" >> $@
#	echo "d2=10.5" >> $@

# get source positions. They're all in a line.
${D}/EW0210_srcpos.H: ${D}/EW0210.H
	Sort3d < $< nkeys=2 key1=s_x ng1=900 dg1=10.36 og1=0 key2=s_y ng2=900 dg2=1.66 og2=0 hff=$@@@ gff=$@@@@@ > $@
	< $@@@ Window3d n1=1 f1=21 > ${D}/s_x.H
	< $@@@ Window3d n1=1 f1=22 > ${D}/s_y.H
	Cmplx ${D}/s_x.H ${D}/s_y.H > $@

# short, intermediate and long offset sections.
${D}/EW0210_short.H: ${D}/EW0210.H
	Window3d < $< min3=4000 max3=9400 min2=-190 max2=-180 min1=3 max1=5.2 > $@

${D}/EW0210_mid.H: ${D}/EW0210.H
	Window3d < $< min3=5000 max3=9050 min2=-3000 max2=-2990 min1=3.9 max1=5.4 > $@

${D}/EW0210_long.H: ${D}/EW0210.H
	Window3d < $< min3=5000 max3=9050 min2=-6000 max2=-5990 min1=5.2 max1=6.7 > $@

EW0210s = ${D}/EW0210_short.H
EW0210m = ${D}/EW0210_mid.H
EW0210l = ${D}/EW0210_long.H

# ocean-bottom reflection wavelet
${R}/EW0210-ob.v: ${D}/EW0210_short.H ${D}/EW0210_mid.H ${D}/EW0210_long.H
	Window3d min2=7203 n2=1 min1=4.048 n1=16 < ${D}/EW0210_short.H > ${D}/short.H
	Window3d min2=7203 n2=1 min1=4.52 n1=16 < ${D}/EW0210_mid.H > ${D}/mid.H
	Window3d min2=7203 n2=1 min1=5.696 n1=16 < ${D}/EW0210_long.H > ${D}/long.H
	Merge ${D}/short.H ${D}/mid.H ${D}/long.H axis=2 space=n | Interp n1out=64 d1out=0.001 | Graph title="comparison of sea-bottom reflection wavelet for different offsets" grid=y d1num=0.008 labelsz=6 legend=y curvelabel="short : middle : long" legendloc="tr" out=$@ > ${dn}


#=====================================================


#==================================
# run decon 
#==================================

# short offset
${D}/EW0210s-t0-perc%-${L}.H: ${EW0210s} ${WAVELET}
	Tpow tpow=${ew0210pow} < ${EW0210s} > ${D}/junk.H
	${LOGDECOBFGS} < ${D}/junk.H niter=300  percentile=$* t2=0 ${eps} lag=${L} \
	filter=${D}/fltEW0210s-t0-perc$*-${L}.H filter_movie=${D}/fltEW0210s-t0-mov.H verb=${VERB} > ${D}/deconEW0210s-t0-perc$*-${L}.H
	${WAVELETCOMP} < ${D}/fltEW0210s-t0-perc$*-${L}.H > $@

${D}/EW0210s-t2-perc%-${L}.H: ${EW0210s} ${WAVELET}
	${LOGDECOBFGS} < ${EW0210s} niter=300 percentile=$* t2=${ew0210pow} ${eps} lag=${L} \
	filter=${D}/fltEW0210s-t2-perc$*-${L}.H filter_movie=${D}/fltEW0210s-t2-mov.H verb=${VERB} > ${D}/deconEW0210s-t2-perc$*-${L}.H
	${WAVELETCOMP} < ${D}/fltEW0210s-t2-perc$*-${L}.H > $@

# middle offset
${D}/EW0210m-t0-perc%-${L}.H: ${EW0210m} ${WAVELET}
	Tpow tpow=${ew0210pow} < ${EW0210m} > ${D}/junk.H
	${LOGDECOBFGS} < ${D}/junk.H niter=300  percentile=$* t2=0 ${eps} lag=${L} \
	filter=${D}/fltEW0210m-t0-perc$*-${L}.H filter_movie=${D}/fltEW0210m-t0-mov.H verb=${VERB} > ${D}/deconEW0210m-t0-perc$*-${L}.H
	${WAVELETCOMP} < ${D}/fltEW0210m-t0-perc$*-${L}.H > $@

${D}/EW0210m-t2-perc%-${L}.H: ${EW0210m} ${WAVELET}
	${LOGDECOBFGS} < ${EW0210m} niter=300 percentile=$* t2=${ew0210pow} ${eps} lag=${L} \
	filter=${D}/fltEW0210m-t2-perc$*-${L}.H filter_movie=${D}/fltEW0210m-t2-mov.H verb=${VERB} > ${D}/deconEW0210m-t2-perc$*-${L}.H
	${WAVELETCOMP} < ${D}/fltEW0210m-t2-perc$*-${L}.H > $@

# long offset
${D}/EW0210l-t0-perc%-${L}.H: ${EW0210l} ${WAVELET}
	Tpow tpow=${ew0210pow} < ${EW0210l} > ${D}/junk.H
	${LOGDECOBFGS} < ${D}/junk.H niter=300  percentile=$* t2=0 ${eps} lag=${L} \
	filter=${D}/fltEW0210l-t0-perc$*-${L}.H filter_movie=${D}/fltEW0210l-t0-mov.H verb=${VERB} > ${D}/deconEW0210l-t0-perc$*-${L}.H
	${WAVELETCOMP} < ${D}/fltEW0210l-t0-perc$*-${L}.H > $@

${D}/EW0210l-t2-perc%-${L}.H: ${EW0210l} ${WAVELET}
	${LOGDECOBFGS} < ${EW0210l} niter=300 percentile=$* t2=${ew0210pow} ${eps} lag=${L} \
	filter=${D}/fltEW0210l-t2-perc$*-${L}.H filter_movie=${D}/fltEW0210l-t2-mov.H verb=${VERB} > ${D}/deconEW0210l-t2-perc$*-${L}.H
	${WAVELETCOMP} < ${D}/fltEW0210l-t2-perc$*-${L}.H > $@

#==================================
# decon figures
#==================================

#==== Compare input to deconed output

# short offset
${R}/Comp-EW0210s-perc%-${L}.v: ${EW0210s} ${D}/EW0210s-t0-perc%-${L}.H ${D}/EW0210s-t2-perc%-${L}.H 
	Tpow < ${EW0210s} tpow=${ew0210pow} | Grey ${titlep} ${greyew0210s} title="Gained short offset" out=${R}/1.v > ${dn}
	Grey < ${D}/deconEW0210s-t0-perc$*-${L}.H ${greyew0210s} ${titlep} title="Gained input deconed short offset lag=${L}"  out=${R}/2.v > ${dn}
	Tpow < ${D}/deconEW0210s-t2-perc$*-${L}.H tpow=${ew0210pow} | Grey ${titlep} ${greyew0210s} title="Gained output deconed short offset lag=${L}" out=${R}/3.v > ${dn}
	vp_SideBySideAniso ${R}/1.v ${R}/2.v ${R}/3.v >  $@
	vp_Movie ${R}/1.v ${R}/2.v ${R}/3.v > $@3
	rm ${R}/[123].v

# middle offset
${R}/Comp-EW0210m-perc%-${L}.v: ${EW0210m} ${D}/EW0210m-t0-perc%-${L}.H ${D}/EW0210m-t2-perc%-${L}.H 
	Tpow < ${EW0210m} tpow=${ew0210pow} | Grey ${titlep} ${greyew0210m} title="Gained mid offset" out=${R}/1.v > ${dn}
	Grey < ${D}/deconEW0210m-t0-perc$*-${L}.H ${greyew0210m} ${titlep} title="Gained input deconed mid offset lag=${L}"  out=${R}/2.v > ${dn}
	Tpow < ${D}/deconEW0210m-t2-perc$*-${L}.H tpow=${ew0210pow} | Grey ${titlep} ${greyew0210m} title="Gained output deconed mid offset lag=${L}" out=${R}/3.v > ${dn}
	vp_SideBySideAniso ${R}/1.v ${R}/2.v ${R}/3.v >  $@
	vp_Movie ${R}/1.v ${R}/2.v ${R}/3.v > $@3
	rm ${R}/[123].v

# long offset
${R}/Comp-EW0210l-perc%-${L}.v: ${EW0210l} ${D}/EW0210l-t0-perc%-${L}.H ${D}/EW0210l-t2-perc%-${L}.H 
	Tpow < ${EW0210l} tpow=${ew0210pow} | Grey ${titlep} ${greyew0210l} title="Gained long offset" out=${R}/1.v > ${dn}
	Grey < ${D}/deconEW0210l-t0-perc$*-${L}.H ${greyew0210l} ${titlep} title="Gained input deconed long offset lag=${L}"  out=${R}/2.v > ${dn}
	Tpow < ${D}/deconEW0210l-t2-perc$*-${L}.H tpow=${ew0210pow} | Grey ${titlep} ${greyew0210l} title="Gained output deconed long offset lag=${L}" out=${R}/3.v > ${dn}
	vp_SideBySideAniso ${R}/1.v ${R}/2.v ${R}/3.v >  $@
	vp_Movie ${R}/1.v ${R}/2.v ${R}/3.v > $@3
	rm ${R}/[123].v


#==== Compare shot waveforms

# short offset
${R}/EW0210s-perc%-${L}.v: ${D}/EW0210s-t0-perc%-${L}.H ${D}/EW0210s-t2-perc%-${L}.H ${B}/ScaleAndClip.x
	cp ${D}/EW0210s-t2-perc$*-${L}.H ${D}/junk1.H
	cp ${D}/EW0210s-t2-perc$*-${L}.H ${D}/junk2.H
	cp ${D}/EW0210s-t0-perc$*-${L}.H  ${D}/junk3.H
	Cat3d ${D}/junk1.H ${D}/junk2.H ${D}/junk3.H | Window3d > ${D}/junk.H
	< ${D}/junk.H ${B}/ScaleAndClip.x scale=3 | Reverse which=2 > ${D}/EW0210s-shot-perc$*-${L}.H
	Dots strings=0 < ${D}/EW0210s-shot-perc$*-${L}.H ${EW0210_SHOTLABEL} gaineach=0 out=$@ > ${dn}

# middle offset
${R}/EW0210m-perc%-${L}.v: ${D}/EW0210m-t0-perc%-${L}.H ${D}/EW0210m-t2-perc%-${L}.H ${B}/ScaleAndClip.x
	cp ${D}/EW0210m-t2-perc$*-${L}.H ${D}/junk1.H
	cp ${D}/EW0210m-t2-perc$*-${L}.H ${D}/junk2.H
	cp ${D}/EW0210m-t0-perc$*-${L}.H  ${D}/junk3.H
	Cat3d ${D}/junk1.H ${D}/junk2.H ${D}/junk3.H | Window3d > ${D}/junk.H
	< ${D}/junk.H ${B}/ScaleAndClip.x scale=3 | Reverse which=2 > ${D}/EW0210m-shot-perc$*-${L}.H
	Dots strings=0 < ${D}/EW0210m-shot-perc$*-${L}.H ${EW0210_SHOTLABEL} gaineach=0 out=$@ > ${dn}

# long offset
${R}/EW0210l-perc%-${L}.v: ${D}/EW0210l-t0-perc%-${L}.H ${D}/EW0210l-t2-perc%-${L}.H ${B}/ScaleAndClip.x
	cp ${D}/EW0210l-t2-perc$*-${L}.H ${D}/junk1.H
	cp ${D}/EW0210l-t2-perc$*-${L}.H ${D}/junk2.H
	cp ${D}/EW0210l-t0-perc$*-${L}.H  ${D}/junk3.H
	Cat3d ${D}/junk1.H ${D}/junk2.H ${D}/junk3.H | Window3d > ${D}/junk.H
	< ${D}/junk.H ${B}/ScaleAndClip.x scale=3 | Reverse which=2 > ${D}/EW0210l-shot-perc$*-${L}.H
	Dots strings=0 < ${D}/EW0210l-shot-perc$*-${L}.H ${EW0210_SHOTLABEL} gaineach=0 out=$@ > ${dn}

decon_EW0210s:
	Rm ${D}/EW0210s-t0-perc50*.H ${D}/EW0210s-t2-perc50*.H; rm -f ${R}/Comp-EW0210s-perc50*.v ${R}/EW0210s-perc50*.v ${R}/Comp-EW0210s-perc50-lags.v
	make ${D}/EW0210s-t0-perc50-${L}.H ${D}/EW0210s-t2-perc50-${L}.H ${R}/Comp-EW0210s-perc50-${L}.v ${R}/EW0210s-perc50-${L}.v tlag=${L}

decon_EW0210m:
	Rm ${D}/EW0210m-t0-perc50*.H ${D}/EW0210m-t2-perc50*.H; rm -f ${R}/Comp-EW0210m-perc50*.v ${R}/EW0210m-perc50*.v ${R}/Comp-EW0210m-perc50-lags.v
	make ${D}/EW0210m-t0-perc50-${L}.H ${D}/EW0210m-t2-perc50-${L}.H ${R}/Comp-EW0210m-perc50-${L}.v ${R}/EW0210m-perc50-${L}.v tlag=${L}

decon_EW0210l:
	Rm ${D}/EW0210l-t0-perc50*.H ${D}/EW0210l-t2-perc50*.H; rm -f ${R}/Comp-EW0210l-perc50*.v ${R}/EW0210l-perc50*.v ${R}/Comp-EW0210l-perc50-lags.v
	make ${D}/EW0210l-t0-perc50-${L}.H ${D}/EW0210l-t2-perc50-${L}.H ${R}/Comp-EW0210l-perc50-${L}.v ${R}/EW0210l-perc50-${L}.v tlag=${L}



#===============================================
# look at the spectrum from one shot (f3=700)
${D}/EW0210_shot700.H: ${D}/EW0210.H
	Window3d < $< n3=1 f3=700 > $@

${D}/EW0210_ft.H: ${D}/EW0210_shot700.H
	Rtoc < $< | Ft3d sign1=-1 sign2=0 | Cabs | Window3d max1=125 > $@

${D}/EW0210_fk.H: ${D}/EW0210_shot700.H
	Pad < $< n2out=512 | Rtoc | Ft3d maxsize=200000000 sign1=-1 sign2=-1 center2=1 | Cabs | Window3d max1=125 > $@

${D}/EW0210_nmo.H: ${D}/EW0210_shot700.H
	Nmo3d < $< vel=1500 maxsize=20000 > $@

${D}/EW0210_nmo_ft.H: ${D}/EW0210_nmo.H
	Rtoc < $< | Ft3d sign1=-1 sign2=0 | Cabs | Window3d max1=125 > $@

${D}/EW0210_nmo_fk.H: ${D}/EW0210_nmo.H
	Pad < $< n2out=512 | Rtoc | Ft3d maxsize=200000000 sign1=-1 sign2=-1 center2=1 | Cabs | Window3d max1=125 > $@

# figures
${R}/EW0210_shot700.v: ${D}/EW0210_shot700.H
	Grey < $< title="shot 700" label1="time (sec)" label2="X (m)" out=$@ > ${dn}

${R}/EW0210_ft.v: ${D}/EW0210_ft.H
	Log < $< | Window3d min1=70 | Grey color=j newclip=1 title="FT shot 700" label1="freq (Hz)" label2="X (m)" out=$@ > ${dn}

${R}/EW0210_fk.v: ${D}/EW0210_fk.H
	Grey < $< color=j newclip=1 title="FK shot 700" label1="freq (Hz)" label2="wavenumber (1/m)" out=$@ > ${dn}

${R}/EW0210_nmo.v: ${D}/EW0210_nmo.H
	Grey < $< title="NMO with vel=water of shot 700" label1="time (sec)" label2="X (m)" out=$@ > ${dn}

${R}/EW0210_nmo_ft.v: ${D}/EW0210_nmo_ft.H
	Grey < $< color=j newclip=1 title="FT of NMO of shot 700" label1="freq (Hz)" label2="X (m)" out=$@ > ${dn}

${R}/EW0210_nmo_fk.v: ${D}/EW0210_nmo_fk.H
	Grey < $< color=j newclip=1 title="FK of NMO of shot 700" label1="freq (Hz)" label2="wavenumber (1/m)" out=$@ > ${dn}

${R}/EW0210-bubblespec.v: ${D}/EW0210_shot700.H
	Window3d < $< min2=-190 n2=1 max1=1 | Spectra | Log | Graph grid=y o1num=6.5 d1num=13 labelsz=6 title="log spectrum of direct arrival" label2="log amplitude" label1="Freqency (Hz)" out=$@ > ${dn}

${R}/EW0210-notch.v: ${D}/EW0210_shot700.H
	Window3d < $< min2=-190 n2=1 min1=3 max1=6 | Spectra | Log | Graph grid=y d1num=10 labelsz=6 title="log spectrum of primary reflections" label2="log amplitude" label1="Freqency (Hz)" out=$@ > ${dn}

shot700_spectra: ${R}/EW0210_shot700.v ${R}/EW0210_ft.v ${R}/EW0210_fk.v ${R}/EW0210_nmo.v ${R}/EW0210_nmo_ft.v ${R}/EW0210_nmo_fk.v
	make ${D}/EW0210_ft.H ${D}/EW0210_fk.H ${D}/EW0210_nmo_ft.H ${D}/EW0210_nmo_fk.H
	make ${R}/EW0210_shot700.v ${R}/EW0210_ft.v ${R}/EW0210_fk.v ${R}/EW0210_nmo.v ${R}/EW0210_nmo_ft.v ${R}/EW0210_nmo_fk.v
	vp_SideBySideAniso ${R}/EW0210_shot700.v ${R}/EW0210_ft.v ${R}/EW0210_fk.v > ${R}/EW0210_spectra.v
	vp_SideBySideAniso ${R}/EW0210_nmo.v ${R}/EW0210_nmo_ft.v ${R}/EW0210_nmo_fk.v > ${R}/EW0210_nmo_spectra.v
	vp_Movie ${R}/EW0210_spectra.v ${R}/EW0210_nmo_spectra.v > ${R}/EW0210_spectra.v3

