L = $(tlag)
ifndef L
    L = 12 
endif

VERB=0

EW05 = /net/server/ohad/dat/EW0210/EW0210_05.H
ew05pow = 2.
pf = 5
scl = 5


# eps is the symmetry regularization, eps1 is the filter length regularization
eps_s = eps=5e+5 eps1=4e+5 lagramp=6
eps_g = eps=1e+8 eps1=1e+8 lagramp=6
eps_0 = eps=0. eps1=0. lagramp=6

# these values are good for the middle offset
#eps = eps=1e+6 eps1=1e+4 and lag of 7

greyew05s = min1=0.35 max1=1.5
greyew05g = min1=0.35 max1=1.5
greyew05all = min1=0.35 max1=3.254


EW05_SHOTLABEL = "labels=shot waveform where data gained AFTER decon : shot waveform where data gained BEFORE decon"

# short, intermediate and long offset sections.
${D}/EW05_short.H: ${EW05}
	Window3d < $< min3=-55000 min2=-190 max2=-180.5 ${greyew05s} > $@

${D}/EW05_mid.H: ${EW05}
	Window3d < $< min3=-55000 min2=-2000 max2=-1990 ${greyew05m} > $@

${D}/EW05_long.H: ${EW05}
	Window3d < $< min3=-55000 min2=-4000 max2=-3990 ${greyew05l} > $@

${D}/EW05_group.H: ${EW05}
	Window3d < $< min3=-55000 min2=-1181 max2=-180.5 ${greyew05g} | Transp plane=23 > $@

${D}/EW05_mask.H:
	Vel n1=288 n2=1149 n3=1 o1=0.348 d1=0.004 o2=0. d2=1. d3=1. vc=0 \
	z1=0.45 vr1=1. const1=1 \
	z2=1.4 vr2=0. const2=1 | Smooth rect1=3 repeat=4 > $@

EW05s = ${D}/EW05_short.H
EW05m = ${D}/EW05_mid.H
EW05l = ${D}/EW05_long.H
EW05g = ${D}/EW05_group.H
EW05mask = ${D}/EW05_mask.H

${R}/EW05-offsets.v: ${D}/EW05_short.H ${D}/EW05_mid.H ${D}/EW05_long.H
	Grey < ${D}/EW05_short.H title=" " label1="time (sec)" label2="X (m)" out=${R}/EW05-short.v > ${dn}
	Grey < ${D}/EW05_mid.H   title=" " label1="time (sec)" label2="X (m)" out=${R}/EW05-mid.v > ${dn}
	Grey < ${D}/EW05_long.H  title=" " label1="time (sec)" label2="X (m)" out=${R}/EW05-long.v > ${dn}
	Grey < ${D}/EW05_short.H title="common offset = 180m"  label1="time (sec)" label2="X (m)" ${greyew05all} out=${R}/1.v > ${dn}
	Grey < ${D}/EW05_mid.H   title="common offset = 2000m" label1="time (sec)" label2="X (m)" ${greyew05all} out=${R}/2.v > ${dn}
	Grey < ${D}/EW05_long.H  title="common offset = 4000m" label1="time (sec)" label2="X (m)" ${greyew05all} out=${R}/3.v > ${dn}
	vp_SideBySideAniso ${R}/1.v ${R}/2.v ${R}/3.v > $@
	rm ${R}/[123].v

# ocean-bottom reflection wavelet
${R}/EW05-ob.v: ${D}/EW05_short.H ${D}/EW05_mid.H
	Window3d min2=-44600 n2=1 min1=0.690 n1=12 < ${D}/EW05_short.H > ${D}/short.H
	Window3d min2=-44600 n2=1 min1=1.500 n1=12 < ${D}/EW05_mid.H   > ${D}/mid.H
	Merge ${D}/short.H ${D}/mid.H axis=2 space=n | Interp n1out=48 d1out=0.001 | Graph min2=-1300 max2=1300 label1="time (sec)" label2="amplitude" title=" " grid=y d1num=0.008 d2num=3000 labelsz=6 legend=y curvelabel="off=180m:off=2000m" legendloc="tr" out=$@ > ${dn}

#=====================================================


#==================================
# run decon 
#==================================

# near offset
${D}/EW05s-t0-${L}.H: ${EW05s} ${WAVELETCOMP}
	Tpow tpow=${ew05pow} < ${EW05s} > ${D}/junk-${L}.H
	${LOGDECOBFGS} < ${D}/junk-${L}.H niter=300  percentile=50 t2=0 ${eps_0} lag=${L} \
	filter=${D}/fltEW05s-t0-${L}.H verb=${VERB} > ${D}/deconEW05s-t0-${L}.H
	${WAVELETCOMP} < ${D}/fltEW05s-t0-${L}.H > $@

${D}/EW05s-t2-${L}.H: ${EW05s} ${WAVELETCOMP}
	${LOGDECOBFGS} < ${EW05s} niter=300 percentile=50 t2=${ew05pow} ${eps_0} lag=${L} \
	filter=${D}/fltEW05s-t2-${L}.H verb=${VERB} > ${D}/deconEW05s-t2-${L}.H
	${WAVELETCOMP} < ${D}/fltEW05s-t2-${L}.H > $@

# near offset group
${D}/EW05g-t0-${L}.H: ${EW05g} ${WAVELETCOMP}
	Tpow tpow=${ew05pow} < ${EW05g} > ${D}/junk-${L}.H
	${LOGDECOBFGS} < ${D}/junk-${L}.H niter=300  percentile=50 t2=0 ${eps_0} lag=${L} \
	filter=${D}/fltEW05g-t0-${L}.H verb=${VERB} > ${D}/deconEW05g-t0-${L}-group.H
	Window3d < ${D}/deconEW05g-t0-${L}-group.H min3=-190 n3=1 > ${D}/deconEW05g-t0-${L}.H
	${WAVELETCOMP} < ${D}/fltEW05g-t0-${L}.H > $@

${D}/EW05g-t2-${L}.H: ${EW05g} ${WAVELETCOMP}
	${LOGDECOBFGS} < ${EW05g} niter=300 percentile=50 t2=${ew05pow} ${eps_0} lag=${L} \
	filter=${D}/fltEW05g-t2-${L}.H verb=${VERB} > ${D}/deconEW05g-t2-${L}-group.H
	Window3d < ${D}/deconEW05g-t2-${L}-group.H min3=-190 n3=1 > ${D}/deconEW05g-t2-${L}.H
	${WAVELETCOMP} < ${D}/fltEW05g-t2-${L}.H > $@

# near offset regularized
${D}/EW05s-t0-reg-${L}.H: ${EW05s} ${WAVELETCOMP}
	Tpow tpow=${ew05pow} < ${EW05s} > ${D}/junk-${L}.H
	${LOGDECOBFGS} < ${D}/junk-${L}.H niter=300  percentile=50 t2-reg=0 ${eps_s} lag=${L} \
	filter=${D}/fltEW05s-t0-reg-${L}.H verb=${VERB} > ${D}/deconEW05s-t0-reg-${L}.H
	${WAVELETCOMP} < ${D}/fltEW05s-t0-reg-${L}.H > $@

${D}/EW05s-t2-reg-${L}.H: ${EW05s} ${WAVELETCOMP}
	${LOGDECOBFGS} < ${EW05s} niter=300 percentile=50 t2-reg=${ew05pow} ${eps_s} lag=${L} \
	filter=${D}/fltEW05s-t2-reg-${L}.H verb=${VERB} > ${D}/deconEW05s-t2-reg-${L}.H
	${WAVELETCOMP} < ${D}/fltEW05s-t2-reg-${L}.H > $@

# near offset group regularized
${D}/EW05g-t0-reg-${L}.H: ${EW05g} ${WAVELETCOMP}
	Tpow tpow=${ew05pow} < ${EW05g} > ${D}/junk-${L}.H
	${LOGDECOBFGS} < ${D}/junk-${L}.H niter=300  percentile=50 t2-reg=0 ${eps_g} lag=${L} \
	filter=${D}/fltEW05g-t0-reg-${L}.H verb=${VERB} > ${D}/deconEW05g-t0-reg-${L}-group.H
	Window3d < ${D}/deconEW05g-t0-reg-${L}-group.H min3=-190 n3=1 > ${D}/deconEW05g-t0-reg-${L}.H
	${WAVELETCOMP} < ${D}/fltEW05g-t0-reg-${L}.H > $@

${D}/EW05g-t2-reg-${L}.H: ${EW05g} ${WAVELETCOMP}
	${LOGDECOBFGS} < ${EW05g} niter=300 percentile=50 t2-reg=${ew05pow} ${eps_g} lag=${L} \
	filter=${D}/fltEW05g-t2-reg-${L}.H verb=${VERB} > ${D}/deconEW05g-t2-reg-${L}-group.H
	Window3d < ${D}/deconEW05g-t2-reg-${L}-group.H min3=-190 n3=1 > ${D}/deconEW05g-t2-reg-${L}.H
	${WAVELETCOMP} < ${D}/fltEW05g-t2-reg-${L}.H > $@

#==================================
# decon figures
#==================================

#==== Compare input to deconed output

# near offset
${R}/EW05s.v: ${EW05s}
	Tpow < ${EW05s} tpow=${ew05pow} | Grey ${titlep} ${greyew05s} out=$@ > ${dn}

# near offset unregularized
${R}/deconEW05s-t0-${L}.v: ${D}/deconEW05s-t0-${L}.H
	Grey < $< ${greyew05s} ${titlep} out=$@ > ${dn}
${R}/deconEW05s-t2-${L}.v: ${D}/deconEW05s-t2-${L}.H
	Tpow < $< tpow=${ew05pow} | Grey ${greyew05s} ${titlep} out=$@ > ${dn}

# near offset regularized
${R}/deconEW05s-t0-reg-${L}.v: ${D}/deconEW05s-t0-reg-${L}.H
	Grey < $< ${greyew05s} ${titlep} out=$@ > ${dn}
${R}/deconEW05s-t2-reg-${L}.v: ${D}/deconEW05s-t2-reg-${L}.H
	Tpow < $< tpow=${ew05pow} | Grey ${greyew05s} ${titlep} out=$@ > ${dn}

# near offset group
${R}/EW05g.v: ${EW05g}
	Window3d < ${EW05g} min3=-190 n3=1 | Tpow tpow=${ew05pow} | Grey ${titlep} ${greyew05g} out=$@ > ${dn}

# near offset group unregularized
${R}/deconEW05g-t0-${L}.v: ${D}/deconEW05g-t0-${L}.H
	Grey < $< ${greyew05g} ${titlep} out=$@ > ${dn}
${R}/deconEW05g-t2-${L}.v: ${D}/deconEW05g-t2-${L}.H
	Tpow < $< tpow=${ew05pow} | Grey ${greyew05g} ${titlep} out=$@ > ${dn}

# near offset group regularized
${R}/deconEW05g-t0-reg-${L}.v: ${D}/deconEW05g-t0-reg-${L}.H
	Grey < $< ${greyew05g} ${titlep} out=$@ > ${dn}
${R}/deconEW05g-t2-reg-${L}.v: ${D}/deconEW05g-t2-reg-${L}.H
	Tpow < $< tpow=${ew05pow} | Grey ${greyew05g} ${titlep} out=$@ > ${dn}

#==== Compare shot waveforms

# near offset
${R}/EW05s-${L}.v: ${D}/EW05s-t0-${L}.H ${D}/EW05s-t2-${L}.H ${B}/ScaleAndClip.x
	Cat3d ${D}/EW05s-t0-${L}.H ${D}/EW05s-t2-${L}.H | Window3d | ${B}/ScaleAndClip.x scale=${scl} > ${D}/EW05s-shot-${L}.H
	Window3d < ${D}/EW05s-shot-${L}.H n2=1 f2=0 > ${D}/EW05s-t0-${L}-clip.H
	Window3d < ${D}/EW05s-shot-${L}.H n2=1 f2=1 > ${D}/EW05s-t2-${L}-clip.H
	echo "o2=0." >> ${D}/EW05s-t2-${L}-clip.H
	Merge ${D}/EW05s-t0-${L}.H ${D}/EW05s-t0-${L}-clip.H axis=2 space=n | Wiggle plotfat=4 pclip=100 min1=-0.4 max1=0.4 min2=-1 max2=2 label1="time (sec)" title=" " out=${R}/EW05s-t0-${L}.v > ${dn}
	Merge ${D}/EW05s-t2-${L}.H ${D}/EW05s-t2-${L}-clip.H axis=2 space=n | Wiggle plotfat=4 pclip=100 min1=-0.4 max1=0.4 min2=-1 max2=2 label1="time (sec)" title=" " out=${R}/EW05s-t2-${L}.v > ${dn}

# near offset group
${R}/EW05g-${L}.v: ${D}/EW05g-t0-${L}.H ${D}/EW05g-t2-${L}.H ${B}/ScaleAndClip.x
	Cat3d ${D}/EW05g-t0-${L}.H ${D}/EW05g-t2-${L}.H | Window3d | ${B}/ScaleAndClip.x scale=${scl} > ${D}/EW05g-shot-${L}.H
	Window3d < ${D}/EW05g-shot-${L}.H n2=1 f2=0 > ${D}/EW05g-t0-${L}-clip.H
	Window3d < ${D}/EW05g-shot-${L}.H n2=1 f2=1 > ${D}/EW05g-t2-${L}-clip.H
	echo "o2=0." >> ${D}/EW05g-t2-${L}-clip.H
	Merge ${D}/EW05g-t0-${L}.H ${D}/EW05g-t0-${L}-clip.H axis=2 space=n | Wiggle plotfat=4 pclip=100 min1=-0.4 max1=0.4 min2=-1 max2=2 label1="time (sec)" title=" " out=${R}/EW05g-t0-${L}.v > ${dn}
	Merge ${D}/EW05g-t2-${L}.H ${D}/EW05g-t2-${L}-clip.H axis=2 space=n | Wiggle plotfat=4 pclip=100 min1=-0.4 max1=0.4 min2=-1 max2=2 label1="time (sec)" title=" " out=${R}/EW05g-t2-${L}.v > ${dn}

# near offset regularized
${R}/EW05s-reg-${L}.v: ${D}/EW05s-t0-reg-${L}.H ${D}/EW05s-t2-reg-${L}.H ${B}/ScaleAndClip.x
	Cat3d ${D}/EW05s-t0-reg-${L}.H ${D}/EW05s-t2-reg-${L}.H | Window3d | ${B}/ScaleAndClip.x scale=${scl} > ${D}/EW05s-shot-reg-${L}.H
	Window3d < ${D}/EW05s-shot-reg-${L}.H n2=1 f2=0 > ${D}/EW05s-t0-reg-${L}-clip.H
	Window3d < ${D}/EW05s-shot-reg-${L}.H n2=1 f2=1 > ${D}/EW05s-t2-reg-${L}-clip.H
	echo "o2=0." >> ${D}/EW05s-t2-reg-${L}-clip.H
	Merge ${D}/EW05s-t0-reg-${L}.H ${D}/EW05s-t0-reg-${L}-clip.H axis=2 space=n | Wiggle plotfat=4 pclip=100 min1=-0.4 max1=0.4 min2=-1 max2=2 label1="time (sec)" title=" " out=${R}/EW05s-t0-reg-${L}.v > ${dn}
	Merge ${D}/EW05s-t2-reg-${L}.H ${D}/EW05s-t2-reg-${L}-clip.H axis=2 space=n | Wiggle plotfat=4 pclip=100 min1=-0.4 max1=0.4 min2=-1 max2=2 label1="time (sec)" title=" " out=${R}/EW05s-t2-reg-${L}.v > ${dn}

# near offset group regularized
${R}/EW05g-reg-${L}.v: ${D}/EW05g-t0-reg-${L}.H ${D}/EW05g-t2-reg-${L}.H ${B}/ScaleAndClip.x
	Cat3d ${D}/EW05g-t0-reg-${L}.H ${D}/EW05g-t2-reg-${L}.H | Window3d | ${B}/ScaleAndClip.x scale=${scl} > ${D}/EW05g-shot-reg-${L}.H
	Window3d < ${D}/EW05g-shot-reg-${L}.H n2=1 f2=0 > ${D}/EW05g-t0-reg-${L}-clip.H
	Window3d < ${D}/EW05g-shot-reg-${L}.H n2=1 f2=1 > ${D}/EW05g-t2-reg-${L}-clip.H
	echo "o2=0." >> ${D}/EW05g-t2-reg-${L}-clip.H
	Merge ${D}/EW05g-t0-reg-${L}.H ${D}/EW05g-t0-reg-${L}-clip.H axis=2 space=n | Wiggle plotfat=4 pclip=100 min1=-0.4 max1=0.4 min2=-1 max2=2 label1="time (sec)" title=" " out=${R}/EW05g-t0-reg-${L}.v > ${dn}
	Merge ${D}/EW05g-t2-reg-${L}.H ${D}/EW05g-t2-reg-${L}-clip.H axis=2 space=n | Wiggle plotfat=4 pclip=100 min1=-0.4 max1=0.4 min2=-1 max2=2 label1="time (sec)" title=" " out=${R}/EW05g-t2-reg-${L}.v > ${dn}

#==== Compare spectra

# near offset
${R}/spec-EW05s.v: ${EW05s}
	Spectra < $< | Log | Grey color=j newclip=1  bclip=-1.4 eclip=1.2 wantscalebar=y barlabel="Log amplitude spectrum" title=" " label1="Frequency (Hz)" label2="surface location (m)" out=$@ > ${dn}

${R}/spec-EW05s-t0-${L}.v: ${D}/deconEW05s-t0-${L}.H
	Spectra < $< | Log | Grey color=j newclip=1  bclip=-1.4 eclip=1.2 wantscalebar=y barlabel="Log amplitude spectrum" title=" " label1="Frequency (Hz)" label2="surface location (m)" out=$@ > ${dn}

${R}/spec-EW05s-t2-${L}.v: ${D}/deconEW05s-t2-${L}.H
	Spectra < $< | Log | Grey color=j newclip=1  bclip=-1.4 eclip=1.2 wantscalebar=y barlabel="Log amplitude spectrum" title=" " label1="Frequency (Hz)" label2="surface location (m)" out=$@ > ${dn}

# near offset group
${R}/spec-EW05g.v: ${EW05g}
	Window3d < $< min3=-190 n3=1 | Spectra | Log | Grey color=j newclip=1  bclip=-1.4 eclip=1.2 wantscalebar=y barlabel="Log amplitude spectrum" title=" " label1="Frequency (Hz)" label2="surface location (m)" out=$@ > ${dn}

${R}/spec-EW05g-t0-${L}.v: ${D}/deconEW05g-t0-${L}.H
	Spectra < $< | Log | Grey color=j newclip=1  bclip=-1.4 eclip=1.2 wantscalebar=y barlabel="Log amplitude spectrum" title=" " label1="Frequency (Hz)" label2="surface location (m)" out=$@ > ${dn}

${R}/spec-EW05g-t2-${L}.v: ${D}/deconEW05g-t2-${L}.H
	Spectra < $< | Log | Grey color=j newclip=1  bclip=-1.4 eclip=1.2 wantscalebar=y barlabel="Log amplitude spectrum" title=" " label1="Frequency (Hz)" label2="surface location (m)" out=$@ > ${dn}

# near offset regularized
${R}/spec-EW05s-t0-reg-${L}.v: ${D}/deconEW05s-t0-reg-${L}.H
	Spectra < $< | Log | Grey color=j newclip=1  bclip=-1.4 eclip=1.2 wantscalebar=y barlabel="Log amplitude spectrum" title=" " label1="Frequency (Hz)" label2="surface location (m)" out=$@ > ${dn}

${R}/spec-EW05s-t2-reg-${L}.v: ${D}/deconEW05s-t2-reg-${L}.H
	Spectra < $< | Log | Grey color=j newclip=1  bclip=-1.4 eclip=1.2 wantscalebar=y barlabel="Log amplitude spectrum" title=" " label1="Frequency (Hz)" label2="surface location (m)" out=$@ > ${dn}

# near offset group regularized
${R}/spec-EW05g-t0-reg-${L}.v: ${D}/deconEW05g-t0-reg-${L}.H
	Spectra < $< | Log | Grey color=j newclip=1  bclip=-1.4 eclip=1.2 wantscalebar=y barlabel="Log amplitude spectrum" title=" " label1="Frequency (Hz)" label2="surface location (m)" out=$@ > ${dn}

${R}/spec-EW05g-t2-reg-${L}.v: ${D}/deconEW05g-t2-reg-${L}.H
	Spectra < $< | Log | Grey color=j newclip=1  bclip=-1.4 eclip=1.2 wantscalebar=y barlabel="Log amplitude spectrum" title=" " label1="Frequency (Hz)" label2="surface location (m)" out=$@ > ${dn}

decon_EW05s:
	#Rm ${D}/EW05s-t0-${L}.H ${D}/EW05s-t2-${L}.H
	#Rm ${D}/EW05s-t0-reg-${L}.H ${D}/EW05s-t2-reg-${L}.H
	make ${D}/EW05s-t0-${L}.H ${D}/EW05s-t2-${L}.H tlag=6
	make ${D}/EW05s-t0-reg-${L}.H ${D}/EW05s-t2-reg-${L}.H tlag=6

decon_EW05g:
	#Rm ${D}/EW05g-t0-${L}.H ${D}/EW05g-t2-${L}.H
	#Rm ${D}/EW05g-t0-reg-${L}.H ${D}/EW05g-t2-reg-${L}.H
	make ${D}/EW05g-t0-${L}.H ${D}/EW05g-t2-${L}.H tlag=6
	make ${D}/EW05g-t0-reg-${L}.H ${D}/EW05g-t2-reg-${L}.H tlag=6

ER:
	make ${B}/Sparse_decon_bfgs
	make decon_EW05s tlag=6
	make decon_EW05g tlag=6
	make ${R}/EW05s.v ${R}/deconEW05s-t0-${L}.v ${R}/deconEW05s-t2-${L}.v ${R}/EW05s-${L}.v tlag=${L} 
	make ${R}/deconEW05s-t0-reg-${L}.v ${R}/deconEW05s-t2-reg-${L}.v ${R}/EW05s-reg-${L}.v tlag=${L}
	make ${R}/EW05g.v ${R}/deconEW05g-t0-${L}.v ${R}/deconEW05g-t2-${L}.v ${R}/EW05g-${L}.v tlag=${L}
	make ${R}/deconEW05g-t0-reg-${L}.v ${R}/deconEW05g-t2-reg-${L}.v ${R}/EW05g-reg-${L}.v tlag=${L}
	make ${R}/spec-EW05s.v ${R}/spec-EW05s-t0-${L}.v ${R}/spec-EW05s-t2-${L}.v ${R}/spec-EW05s-t0-reg-${L}.v ${R}/spec-EW05s-t2-reg-${L}.v tlag=6
	make ${R}/spec-EW05g.v ${R}/spec-EW05g-t0-${L}.v ${R}/spec-EW05g-t2-${L}.v ${R}/spec-EW05g-t0-reg-${L}.v ${R}/spec-EW05g-t2-reg-${L}.v tlag=6
	make ${R}/EW05s.pdf ${R}/deconEW05s-t0-${L}.pdf ${R}/deconEW05s-t2-${L}.pdf ${R}/deconEW05s-t0-reg-${L}.pdf ${R}/deconEW05s-t2-reg-${L}.pdf tlag=6
	make ${R}/EW05g.pdf ${R}/deconEW05g-t0-${L}.pdf ${R}/deconEW05g-t2-${L}.pdf ${R}/deconEW05g-t0-reg-${L}.pdf ${R}/deconEW05g-t2-reg-${L}.pdf tlag=6
	make ${R}/EW05s-t0-${L}.pdf ${R}/EW05s-t2-${L}.pdf ${R}/EW05g-t0-${L}.pdf ${R}/EW05g-t2-${L}.pdf tlag=6
	make ${R}/EW05s-t0-reg-${L}.pdf ${R}/EW05s-t2-reg-${L}.pdf ${R}/EW05g-t0-reg-${L}.pdf ${R}/EW05g-t2-reg-${L}.pdf tlag=6
	make ${R}/spec-EW05s.pdf ${R}/spec-EW05s-t0-${L}.pdf ${R}/spec-EW05s-t2-${L}.pdf ${R}/spec-EW05s-t0-reg-${L}.pdf ${R}/spec-EW05s-t2-reg-${L}.pdf tlag=6
	make ${R}/spec-EW05g.pdf ${R}/spec-EW05g-t0-${L}.pdf ${R}/spec-EW05g-t2-${L}.pdf ${R}/spec-EW05g-t0-reg-${L}.pdf ${R}/spec-EW05g-t2-reg-${L}.pdf tlag=6
	make shot992_spectra
	make ${R}/EW05-shot992.pdf ${R}/EW05-ft.pdf ${R}/EW05-nmo.pdf ${R}/EW05-nmo-ft.pdf
	make ${R}/EW05-bubble.pdf ${R}/EW05-bubblespec.pdf ${R}/EW05-notch.pdf ${R}/EW05-notchspec.pdf
	rm ${R}/*.ps ${R}/*.v

#===============================================
# look at the spectrum from one shot (f3=992)
${D}/EW05_shot992.H: ${EW05}
	#Window3d < $< min1=0.7 n1=512 min2=-1500 n3=1 f3=992 > $@
	Window3d < $< n1=512 min2=-1500 n3=1 f3=992 > $@

${D}/EW05_ft.H: ${D}/EW05_shot992.H
	Rtoc < $< | Ft3d sign1=-1 sign2=0 | Cabs | Log | Window3d max1=125 > $@

${D}/EW05_nmo.H: ${D}/EW05_shot992.H
	Nmo3d < $< vel=1500 maxsize=20000 > $@

${D}/EW05_nmo_ft.H: ${D}/EW05_nmo.H
	Rtoc < $< | Ft3d sign1=-1 sign2=0 | Cabs | Log | Window3d max1=125 > $@

# figures
${R}/EW05-shot992.v: ${D}/EW05_shot992.H
	Grey < $< title=" " label1="time (sec)" label2="X (m)" max1=2 out=$@ > ${dn}

${R}/EW05-ft.v: ${D}/EW05_ft.H
	Grey < $< color=j newclip=1 title=" " label1="Frequency (Hz)" label2="X (m)" wantscalebar=y barlabel="Log amplitude spectrum" out=$@ > ${dn}

${R}/EW05-nmo.v: ${D}/EW05_nmo.H
	Grey < $< title=" " label1="time (sec)" label2="X (m)" max1=2 out=$@ > ${dn}

${R}/EW05-nmo-ft.v: ${D}/EW05_nmo_ft.H
	Grey < $< color=j newclip=1 title=" " label1="Frequency (Hz)" label2="X (m)" out=$@ > ${dn}

${R}/EW05-bubble.v: ${EW05}
	Window3d < $< min2=-190 n2=1 max1=0.6 n3=1 min3=-46140 | Graph labelsz=6 title=" " label1="time (sec)" label2="Amplitude (millivolt)" plotfat=${pf} out=$@ > ${dn}

${R}/EW05-bubblespec.v: ${EW05}
	Window3d < $< min2=-190 n2=1 max1=0.6 n3=1 min3=-46140 | Spectra | Log | Graph grid=y d1num=10 labelsz=6 title=" " label2="log amplitude" label1="Frequency (Hz)" plotfat=${pf} out=$@ > ${dn}

${R}/EW05-notch.v: ${EW05}
	Window3d < $< min2=-190 n2=1 max1=2 n3=1 min3=-46140 | Graph labelsz=6 title=" " label1="time (sec)" label2="Amplitude (millivolt)" plotfat=${pf} out=$@ > ${dn}

${R}/EW05-notchspec.v: ${EW05}
	Window3d < $< min2=-190 n2=1 max1=2 n3=1 min3=-46140 | Spectra | Log | Graph grid=y d1num=10 labelsz=6 title=" " label2="log amplitude" label1="Frequency (Hz)" plotfat=${pf} out=$@ > ${dn}

shot992_spectra: ${R}/EW05-shot992.v ${R}/EW05-ft.v ${R}/EW05-nmo.v ${R}/EW05-nmo-ft.v
	Rm ${D}/EW05_shot992.H ${D}/EW05_nmo.H ${D}/EW05_ft.H ${D}/EW05_nmo_ft.H
	make ${D}/EW05_shot992.H ${D}/EW05_ft.H ${D}/EW05_nmo.H ${D}/EW05_nmo_ft.H
	make ${R}/EW05-shot992.v ${R}/EW05-ft.v ${R}/EW05-nmo.v ${R}/EW05-nmo-ft.v
	#rm ${R}/EW05-bubble.v ${R}/EW05-bubblespec.v ${R}/EW05-notch.v ${R}/EW05-notchspec.v
	make ${R}/EW05-bubble.v ${R}/EW05-bubblespec.v ${R}/EW05-notch.v ${R}/EW05-notchspec.v

