program Sparse_Decon_LBFGS

	use sep
	use sfft_mod
	use quantile_calc_mod

	implicit none

	
	real,       dimension(:,:),   allocatable :: in,gin  ! input data
	complex,    dimension(:,:),   allocatable :: inw,ginw! input Fourier domain
	real,       dimension(:,:),   allocatable :: gt      ! gain function
	real,       dimension(:,:),   allocatable :: qt
	real,       dimension(:,:),   allocatable :: rt,rtmp
	real,       dimension(:),     allocatable :: regt
	real,       dimension(:),     allocatable :: reg2t
	
	real,             dimension(:), allocatable :: ut, dut ! filter time domain
	double precision, dimension(:), allocatable :: ut_dp,dut_dp,ut_save
	real,             dimension(:), allocatable :: tmp1, utb

	double complex, dimension(:), allocatable :: euw
	complex,        dimension(:), allocatable :: uw, duw
	complex,        dimension(:), allocatable :: tmp,tmp2

	integer,    dimension(:),     allocatable :: n
	real,       dimension(:),     allocatable :: o, d
	integer(8), dimension(:),     allocatable :: plan1,plan2
	logical,    parameter                     :: FORWARD=.FALSE.,BACKWARD=.TRUE.

	character(len=1024) :: label
	integer :: i,j,it,n_dim,nt,nt2,n23,nw,nq,max_iter,neval,count,symlag,lagramp,verb
	real    :: ow,dw,dt,ot,oky,dky,percentile,t,t2,maxin,quant,weight,symeps,qbar,tlimeps,tlimit
	logical :: zero_neg,new_init

	!LBFGS arrays
	double precision, dimension(:), allocatable :: wd
	double precision, dimension(:), allocatable :: diagd

	real             :: f
	double precision :: fd

	integer,dimension(2) :: iprint
	double precision     :: EPS,XTOL
	
	logical              :: cont
	integer              :: iter,info,ntlimit
	integer              :: stat2,iflag,myinfo
	
	DOUBLE PRECISION GTOL,STPMIN,STPMAX
	INTEGER MP,LP,NDIM,NWORK,MSAVE

	external :: LB2
	COMMON /LB3/MP,LP,GTOL,STPMIN,STPMAX

	call sep_init(SOURCE)
	n_dim=sep_dimension()
	allocate(n(n_dim),o(n_dim),d(n_dim))

	do i=1,n_dim
		call sep_get_data_axis_par("in",i,n(i),o(i),d(i),label)
	end do

	call from_param('t2',t2,0.)

	nt=n(1); dt=d(1); ot=o(1)

	!LBFGS INIT 
	NDIM=nt
	MSAVE=5
	NWORK=NDIM*(2*MSAVE+1)+2*MSAVE

	call from_param('verb',verb,0)

	iprint(1)=verb
	iprint(2)=0
	XTOL=epsilon(XTOL)
	EPS=1.0D-20

	if (n_dim.ge.2) then
		n23=product(n(2:))
	else
		n23=1
	end if
	nw=nt/2+1
	nt2=nt/2

	call from_param ('lag',			symlag, 12)
	call from_param ('lagramp',		lagramp, INT(symlag))
	call from_param ('tlimit',		tlimit, nt2*d(1)/3)
	call from_param ('eps',			symeps, 1.)
	call from_param ('eps1',		tlimeps, 1.)
	call from_param ('zero_neg',	zero_neg,.false.)
	call from_param ('new_init',	new_init,.false.)
	call from_param ('percentile',	percentile,90.)

	if ((percentile .lt. 1) .or. (percentile .gt. 100.)) then
		call erexit('ERROR: percentile must be between 0 and 100')
	end if

	ntlimit=tlimit/d(1)
	if (ntlimit.gt.nt2) then
		write(0,*) 'INFO: tlimit is too big>',nt2,'change tlimit to nt/2'
		ntlimit=nt2
	end if
 
	allocate(in(nt,n23),gt(nt,n23))
	gt=1.
	if (exist_file('gain')) then
		call sreed('gain',gt,4*nt*n23)
	end if

	do i=1,nt
		t=(i-1)*dt+ot
		gt(i,:)=t**t2*gt(i,:)
	end do

	if (exist_file('gt')) then
		call srite('gt',gt,4*nt*n23)
		call to_history('n1',nt,'gt')
		call to_history('d1',dt,'gt')
		call to_history('o1',ot,'gt')
		call to_history('n2',n23,'gt')
		call to_history('d2',d(2),'gt')
		call to_history('o2',o(2),'gt')
	end if

	allocate(wd(NWORK))  
	allocate(diagd(NDIM))
	allocate(dut_dp(NDIM))! double precision
	allocate(dut(NDIM))   ! single precision
	allocate(ut_dp(NDIM)) ! double precision
	allocate(ut(NDIM))    ! single precision
	
	iter=0
	iflag=0
	cont=.true.
	myinfo=0
	info=0
	count=0 

	call from_param('niter',max_iter,10)
	neval=max_iter

	allocate(plan1(2),plan2(2))
	write(0,*) 'INFO: Initialize FFT plans'
	call init_fft_dimension_1d_r2c_c2r(nt,dt,dw,ow)
	call initialize_fft1d_r2c_c2r(plan1)

	allocate(inw(nw,n23))
	call sreed('in',in,4*nt*n23)

	write(0,*) 'INFO: FFT input data'
	call fft1d_r2c_c2r_n23(in,inw,n23,plan1,FORWARD)

	allocate(uw(nw),duw(nw),euw(nw),tmp(nw),tmp2(nw))
	allocate(rt(nt,n23),rtmp(nt,n23),qt(nt,n23),regt(nt),reg2t(nt))

	ut=0.
	uw=0.
	if (new_init) then
		allocate(ginw(nw,n23),gin(nt,n23))
		gin=gt*in
		call fft1d_r2c_c2r_n23(gin,ginw,n23,plan1,FORWARD)     
		allocate(utb(nt))
		! Forming the regularization array utb
		tmp=0.
		do j=1,n23
			tmp=tmp+ginw(:,j)*conjg(ginw(:,j))
		end do
		tmp=sqrt(real(tmp))
		uw=clog(tmp)
		uw=uw-sum(uw)/nw
		call fft1d_r2c_c2r_n23(utb,uw,1,plan1,BACKWARD)
		call mostly_causal_amplitude(utb,nt,symlag)
		call fft1d_r2c_c2r_n23(utb,uw,1,plan1,FORWARD)
		ut=-utb
		uw=-uw
		deallocate(gin,ginw,utb)
		
	end if

	if (exist_file('utb')) then
		call srite('utb',uw,8*nw)
		call to_history('n1',nw,'utb')
		call to_history('d1',dw,'utb')
		call to_history('o1',ot,'utb')
		call to_history('n2',1,'utb')
		call to_history('n3',1,'utb')
		call to_history('nt',nt,'utb')
		call to_history('ot',ot,'utb')
		call to_history('dt',dt,'utb')
		call to_history('esize',8,'utb')
	end if

	allocate(tmp1(nt*n23))

	do j=1,n23
		tmp=inw(:,j)*exp(uw)
		call fft1d_r2c_c2r_n23(rt(:,j),tmp,1,plan1,BACKWARD) ! r  = IFT(D*exp(U))
	end do

	do i=1,n23
		do j=1,nt
			tmp1(j+(i-1)*nt)=abs(rt(j,i)*gt(j,i))
		end do
	end do

	nq=size(in)*percentile/100.
	quant=quantile_calc(nq,tmp1); deallocate(tmp1)

	allocate(tmp1(nt))

	if (quant.eq.0.) then
		write(0,*) 'INFO: quant=',quant
		write(0,*) 'INFO: replace quant with maxval'
		quant=maxval(abs(rt*gt))
	end if

	write(0,*) 'INFO:',percentile,'th percentile gained data=',quant

	gt=gt/quant
	qt=gt*rt

	duw=0.
	euw=0.

	do while (cont)

		fd=0.
		duw=0.
		dut=0.

		! Compute gradient and function
		call fft1d_r2c_c2r_n23(ut,uw,1,plan1,FORWARD)

		! symmetry regularization
		regt=0.
		do it=2,symlag
			weight           = cos (.5*pi*(it-1)/(symlag-1))**2
			regt(it)         = weight * (ut(it)-ut(2*nt2-it+2))
			regt(2*nt2-it+2) = weight * (ut(2*nt2-it+2)-ut(it))
		end do

		regt(1)=0.     ! Zero freq
		regt(nt2+1)=0. ! Nyquist

		fd=symeps*sum(dprod(regt,regt))*0.5

		! time limit of filter regularization
		reg2t=0.
		do it=1,lagramp
			weight			= sin (.5*pi*(it-1)/(lagramp-1))**2
			reg2t(nt-it+1)	= weight * ut(nt-it+1)
		end do

		do it=1,lagramp
			weight				= cos (.5*pi*(it-1)/(lagramp-1))**2
			reg2t(ntlimit-it+1) = weight * ut(ntlimit-it+1)
		end do

		reg2t(ntlimit+1:nt-lagramp)=ut(ntlimit+1:nt-lagramp)

		fd=fd+tlimeps*sum(dprod(reg2t,reg2t))*0.5

		euw=exp(uw)

		do j=1,n23
			tmp2=inw(:,j)*euw
			call fft1d_r2c_c2r_n23(rt(:,j),tmp2,1,plan1,BACKWARD)! r  = IFT(D*exp(U))
			qt(:,j)=gt(:,j)*rt(:,j)                              ! q  = g*r
			fd = fd+sum(sqrt(1.d0+qt(:,j)**2)-1.d0)              ! f  = f+Sum(sqrt(1+q^2)-1)
			tmp1=gt(:,j)*qt(:,j)/sqrt(qt(:,j)**2+1)              !tmp1= g*softclip(q)
			call fft1d_r2c_c2r_n23(tmp1,tmp,1,plan1,FORWARD)     !tmp = FT(tmp1)
			call fft1d_r2c_c2r_n23(rt(:,j),tmp2,1,plan1,FORWARD) !tmp2= FT(r) 
			duw=duw+conjg(tmp2)*tmp
		end do

		call fft1d_r2c_c2r_n23(dut,duw,1,plan1,BACKWARD)
		dut=dut+symeps*regt+tlimeps*reg2t

		if (zero_neg) then 
			do it=2,lagramp
				weight=cos(.5*pi*(it-1)/(lagramp-1))**2
				dut(nt-it+2) = weight*dut(nt-it+2) 
			end do
			do it=2,lagramp
				weight=sin(.5*pi*(it-1)/(lagramp-1))**2
				dut(ntlimit-it+2) = weight*dut(ntlimit-it+2)
			end do
			dut(ntlimit+2:nt-lagramp+1)=0.
		end if

		! remove mean from dU
		call fft1d_r2c_c2r_n23(dut,duw,1,plan1,FORWARD)
		duw=(duw-sum(duw)/nw)   
		call fft1d_r2c_c2r_n23(dut,duw,1,plan1,BACKWARD)

		dut_dp=dble(dut)
		ut_dp=dble(ut)

		call LBFGS(NDIM,MSAVE,ut_dp,fd,dut_dp,&
		&          .False.,diagd,iprint,EPS,&
		&          XTOL,wd,iflag,myinfo)

		if(myinfo.eq.1) ut_save=ut_dp
		ut=sngl(ut_dp)

		info=myinfo ! myinfo: did the BFGS find a value for the steplength
		if (myinfo.eq.1) then
			myinfo=0
			count=count+1
			if (count.ge.max_iter) cont=.false.

			if (exist_file('movie'))        call srite('movie',rt,4*nt*n23)

			if (exist_file('filter_movie')) then
				call fft1d_r2c_c2r_n23(ut,uw,1,plan1,FORWARD)
				call srite('filter_movie',uw,8*nw)
			end if

			if (exist_file('fct'))          call srite('fct',sngl(fd),4)

			if(exist_file('qbar')) then  ! what is the value of the q=g*r at each new itteration
				qbar=0
				do j=1,n23
					qbar=qbar+sum(sqrt(1.+qt(:,j)**2))
				end do
				qbar=sqrt((qbar/(nt*n23))**2-1)
				call srite('qbar',qbar,4)
			end if

			if (exist_file('qt_movie')) then
				qbar=0
				do j=1,n23
					qbar=qbar+sum(sqrt(1.+qt(:,j)**2))
				end do
				qbar=sqrt((qbar/(nt*n23))**2-1)
				rtmp=qt
				do j=1,50
					rtmp(1:50,j)=qbar
				end do
				do j=n23-50,n23
					rtmp(1:50,j)=-qbar
				end do
				call srite('qt_movie',rtmp,4*nt*n23)
			end if
		end if

		if(iflag.le.0) cont=.false.
		iter=iter+1
		if(iter.ge.neval) cont=.false.

	end do

	call srite('out',rt,4*nt*n23)

	if (exist_file('filter')) then
		call fft1d_r2c_c2r_n23(ut,uw,1,plan1,FORWARD)
		call srite('filter',uw,8*nw)
		call to_history('n1',nw,'filter')
		call to_history('d1',dw,'filter')
		call to_history('n2',1,'filter')
		call to_history('n3',1,'filter')
		call to_history('nt',nt,'filter')
		call to_history('ot',ot,'filter')
		call to_history('dt',dt,'filter')
		call to_history('esize',8,'filter')
	end if

	if (exist_file('qbar')) then
		call to_history('n1',count,'qbar')
		call to_history('d1',1,'qbar')
		call to_history('o1',1,'qbar')
	end if

	if (exist_file('filter_movie')) then
		call to_history('n1',nw,'filter_movie')
		call to_history('d1',dw,'filter_movie')
		call to_history('o1',ot,'filter_movie')
		call to_history('n2',1,'filter_movie')
		call to_history('n3',count,'filter_movie')
		call to_history('nt',nt,'filter_movie')
		call to_history('ot',ot,'filter_movie')
		call to_history('dt',dt,'filter_movie')
		call to_history('esize',8,'filter_movie')

	end if

	if (exist_file('qt_movie')) then
		call to_history('n3',count,'qt_movie')
		call to_history('n2',n23,'qt_movie')
		call to_history('n1',n(1),'qt_movie')
		call to_history('d1',d(1),'qt_movie')
		call to_history('d2',d(2),'qt_movie')
		call to_history('o2',o(2),'qt_movie')
	end if

	if (exist_file('movie')) then
		call to_history('n3',count,'movie')
		call to_history('n2',n23,'movie')
		call to_history('n1',n(1),'movie')
		call to_history('d1',d(1),'movie')
		call to_history('d2',d(2),'movie')
		call to_history('o2',o(2),'movie')
	end if

	if (exist_file('fct')) then
		call to_history('n1',count,'fct')
		call to_history('d1',1,'fct')
		call to_history('o1',1,'fct')
	end if

	call sep_close()

end program Sparse_Decon_LBFGS

subroutine mostly_causal_amplitude(ut,nt,lag)
	integer            ::               nt,lag
	real, dimension(nt)::            ut

	integer :: it,nt2
	real    :: weight, asym
	real	:: pi = 4.*atan(1.)

	nt2=nt/2
	do it=2,nt2
		ut(it)         = 2.*ut(it)
		ut(2*nt2-it+2) = 0.
	end do

	do it=2,lag
		asym=(ut(it)-ut(2*nt2-it+2))/2.
		weight=cos(.5*pi*(it-1)/(lag-1.))**2
!     weight=1
		ut(      it)   = ut(      it)   - weight*asym
		ut(2*nt2-it+2) = ut(2*nt2-it+2) + weight*asym
	end do
	
end subroutine mostly_causal_amplitude
